Struct Stack
Source pub struct Stack<T> {
pub head: Option<Box<StackNode<T>>>,
pub length: u16,
}
Documentation
Safety
As Stack::swap, it swaps a specific item with the head of stack.
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.